@@ -436,18 +436,18 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         if (null == smtpSession) {
             synchronized (this) {
                 if (null == smtpSession) {
-                    Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
+                    final Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
                     smtpProps.put("mail.smtp.class", JavaSMTPTransport.class.getName());
                     smtpProps.put("com.openexchange.mail.maxMailSize", Long.toString(getMaxMailSize()));
 
                     /*
                      * Set properties
                      */
-                    ISMTPProperties smtpProperties = smtpConfig.getSMTPProperties();
+                    final ISMTPProperties smtpProperties = smtpConfig.getSMTPProperties();
                     /*
                      * Check for Kerberos subject
                      */
-                    boolean kerberosAuth = isKerberosAuth();
+                    final boolean kerberosAuth = isKerberosAuth();
                     if (isKerberosAuth()) {
                         smtpProps.put("mail.smtp.auth", "true");
                         smtpProps.put("mail.smtp.sasl.enable", "true");
@@ -459,7 +459,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     /*
                      * Localhost, & timeouts
                      */
-                    String smtpLocalhost = smtpProperties.getSmtpLocalhost();
+                    final String smtpLocalhost = smtpProperties.getSmtpLocalhost();
                     if (smtpLocalhost != null) {
                         smtpProps.put("mail.smtp.localhost", smtpLocalhost);
                     }
@@ -730,11 +730,19 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     auditLogService.log(eventId, DefaultAttribute.valueFor(Name.LOGIN, session.getLoginName()), DefaultAttribute.valueFor(Name.IP_ADDRESS, session.getLocalIp()), DefaultAttribute.timestampFor(new Date()), DefaultAttribute.arbitraryFor("smtp.login", null == login ? "<none>" : login), DefaultAttribute.arbitraryFor("smtp.server", server), DefaultAttribute.arbitraryFor("smtp.port", Integer.toString(port)));
                 }
             }
-        } catch (javax.mail.AuthenticationFailedException e) {
-            if (accountId == Account.DEFAULT_ID) {
-                LOG.warn("", e);
+        } catch (OXException e) {
+            if (accountId == Account.DEFAULT_ID && MimeMailException.isAuthenticationFailedException(e)) {
+                // Do log failed authentication attempts against primary mail server
+                LOG.warn("Failed authentication against primary transport server", e);
             }
-            throw MimeMailExceptionCode.TRANSPORT_INVALID_CREDENTIALS.create(e, smtpConfig.getServer(), e.getMessage());
+            throw e;
+        } catch (javax.mail.AuthenticationFailedException e) {
+            OXException oxe = MimeMailExceptionCode.TRANSPORT_INVALID_CREDENTIALS.create(e, smtpConfig.getServer(), e.getMessage());
+            if (accountId == Account.DEFAULT_ID) {
+                // Do log failed authentication attempts against primary mail server
+                LOG.warn("Failed authentication against primary transport server", oxe);
+            }
+            throw oxe;
         } catch (MessagingException e) {
             if (MimeMailException.isSSLHandshakeException(e)) {
                 List<Object> displayArgs = new ArrayList<>(2);
@@ -813,7 +821,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     switch (type) {
                         case RETRY:
                             transport.connect(host, port, user, password);
-                            break;
+                            return;
                         case EXCEPTION:
                             throw result.getError();
                         default:
